.. multicolorfits documentation master file, created by
   sphinx-quickstart on Sat Sep 28 18:20:48 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

multicolorfits documentation
==========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   multicolorfits
   changelog
   examples
   reference_api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
